# Data Testing

The following is all the tests done on the data entries coming from Strapi. This way we can detect weird situation (missing fields, duplicated values)...

## Contents

| Subitem   | Name                  | Type        | Severity  | Description                                                           | Recommendation                                                                                                                         |
| --------- | --------------------- | ----------- | --------- | --------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------- |
|           | No Category           | Missing     | Medium    | The Content has no Category.                                          | Select a Category in relation with the Content                                                                                         |
|           | No Type               | Missing     | Medium    | The Content has no Category.                                          | If unsure, use the "Other" Category.                                                                                                   |
|           | No Ranged Content     | Improvement | Low       | The Content has no Ranged Content.                                    | If this Content is available in one or multiple Library Item(s), create a Range Content to connect the Content to its Library Item(s). |
|           | Self Recommendation   | Error       | Very High | The Content is referring to itself as a Next or Previous Recommended. |                                                                                                                                        |
|           | No Thumbnail          | Missing     | High      | The Content has no Thumbnail.                                         |                                                                                                                                        |
|           | No Titles             | Missing     | High      | The Content has no Titles.                                            |                                                                                                                                        |
| Titles    | No Title              | Missing     | High      |                                                                       |                                                                                                                                        |
| Titles    | No Language           | Error       | Very High |                                                                       |                                                                                                                                        |
| Titles    | No Description        | Missing     | Medium    |                                                                       |                                                                                                                                        |
| Titles    | Duplicate Language    | Error       | High      |                                                                       |                                                                                                                                        |
|           | No Sets               | Missing     | Medium    | The Content has no Sets.                                              |                                                                                                                                        |
|           | No Video Set          | Missing     | Very Low  | The Content has no Video Set.                                         |                                                                                                                                        |
|           | No Audio Set          | Missing     | Very Low  | The Content has no Audio Set.                                         |                                                                                                                                        |
|           | No Text Set           | Missing     | Medium    | The Content has no Text Set.                                          |                                                                                                                                        |
| Text Sets | No Language           | Error       | Very High |                                                                       |                                                                                                                                        |
| Text Sets | No Source Language    | Error       | Very High |                                                                       |                                                                                                                                        |
| Text Sets | Not Done Status       | Improvement | Low       |                                                                       |                                                                                                                                        |
| Text Sets | No Text               | Missing     | Medium    |                                                                       |                                                                                                                                        |
| Text Sets | No Transcribers       | Missing     | High      | The Content is a Transcription but doesn't credit any Transcribers.   | Add the appropriate Transcribers.                                                                                                      |
| Text Sets | No Translators        | Missing     | High      | The Content is a Translation but doesn't credit any Translators.      | Add the appropriate Translators.                                                                                                       |
| Text Sets | Credited Transcribers | Error       | High      | The Content is a Translation but credits one or more Transcribers.    | If appropriate, create a Transcription Text Set with the Transcriber credited there.                                                   |
| Text Sets | Credited Translators  | Error       | High      | The Content is a Transcription but credits one or more Translators.   | If appropriate, create a Translation Text Set with the Translator credited there.                                                      |
| Text Sets | Duplicate Language    | Error       | High      |                                                                       |                                                                                                                                        |

## LibraryItems

| Subitem              | Name                   | Type        | Severity  | Description                                                           | Recommendation                                                                          |
| -------------------- | ---------------------- | ----------- | --------- | --------------------------------------------------------------------- | --------------------------------------------------------------------------------------- |
|                      | No Category            | Missing     | Medium    | The Item has no Category.                                             | Select a Category in relation with the Item.                                            |
|                      | Disconnected Item      | Error       | Very High | The Item is neither a Root Item, nor is it a subitem of another item. |                                                                                         |
|                      | No Contents            | Missing     | Low       | The Item has no Contents.                                             |                                                                                         |
|                      | No Thumbnail           | Missing     | High      | The Item has no Thumbnail.                                            |                                                                                         |
|                      | No Images              | Missing     | High      | The Item has no Images.                                               |                                                                                         |
| Images               | No Language            | Error       | Very High |                                                                       |                                                                                         |
| Images               | No Source Language     | Error       | Very High |                                                                       |                                                                                         |
| Images               | Not Done Status        | Improvement | Low       |                                                                       |                                                                                         |
| Images               | No Scanners            | Missing     | High      | The Item is a Scan but doesn't credit any Scanners.                   | Add the appropriate Scanners.                                                           |
| Images               | No Cleaners            | Missing     | High      | The Item is a Scan but doesn't credit any Cleaners.                   | Add the appropriate Cleaners.                                                           |
| Images               | Credited Typesetters   | Error       | High      | The Item is a Scan but credits one or more Typesetters.               | If appropriate, create a Scanlation Images Set Set with the Typesetters credited there. |
| Images               | No Typesetters         | Missing     | High      | The Item is a Scanlation but doesn't credit any Typesetters.          | Add the appropriate Typesetters.                                                        |
| Images               | Credited Scanners      | Error       | High      | The Item is a Scanlation but credits one or more Scanners.            | If appropriate, create a Scan Images Set with the Scanners credited there.              |
| Images               | No Cover               | Missing     | High      |                                                                       |                                                                                         |
| Images > Cover       | No Front               | Missing     | Very High |                                                                       |                                                                                         |
| Images > Cover       | No Spine               | Missing     | Low       |                                                                       |                                                                                         |
| Images > Cover       | No Back                | Missing     | High      |                                                                       |                                                                                         |
| Images > Cover       | No Full                | Missing     | Low       |                                                                       |                                                                                         |
| Images               | No Dust Jacket         | Missing     | Very Low  |                                                                       |                                                                                         |
| Images > Dust Jacket | No Front               | Missing     | Very High |                                                                       |                                                                                         |
| Images > Dust Jacket | No Spine               | Missing     | Low       |                                                                       |                                                                                         |
| Images > Dust Jacket | No Back                | Missing     | High      |                                                                       |                                                                                         |
| Images > Dust Jacket | No Flap Front          | Missing     | Medium    |                                                                       |                                                                                         |
| Images > Dust Jacket | No Flat Back           | Missing     | Medium    |                                                                       |                                                                                         |
| Images > Dust Jacket | No Full                | Missing     | Low       |                                                                       |                                                                                         |
| Images               | No Obi Belt            | Missing     | Very Low  |                                                                       |                                                                                         |
| Images > Obi Belt    | No Front               | Missing     | Very High |                                                                       |                                                                                         |
| Images > Obi Belt    | No Spine               | Missing     | Low       |                                                                       |                                                                                         |
| Images > Obi Belt    | No Back                | Missing     | High      |                                                                       |                                                                                         |
| Images > Obi Belt    | No Flap Front          | Missing     | Medium    |                                                                       |                                                                                         |
| Images > Obi Belt    | No Flat Back           | Missing     | Medium    |                                                                       |                                                                                         |
| Images > Obi Belt    | No Full                | Missing     | Low       |                                                                       |                                                                                         |
| Images               | Duplicate Language     | Error       | High      |                                                                       |                                                                                         |
| Description          | No Language            | Error       | Very High |                                                                       |                                                                                         |
| Description          | No Text                | Error       | Very High |                                                                       |                                                                                         |
| Description          | Duplicate Language     | Error       | High      |                                                                       |                                                                                         |
|                      | No URLs                | Missing     | Very Low  | Unless the Item is a Variant Set.                                     |                                                                                         |
|                      | No Release Date        | Missing     | Low       |                                                                       |                                                                                         |
| Release Date         | No Year                | Error       | Very High |                                                                       |                                                                                         |
| Release Date         | No Month               | Missing     | Medium    |                                                                       |                                                                                         |
| Release Date         | No Year                | Missing     | Low       |                                                                       |                                                                                         |
|                      | No Price               | Missing     | Low       |                                                                       |                                                                                         |
| Price                | No Currency            | Error       | Very High | Unless the Item is a Variant Set.                                     |                                                                                         |
| Price                | No Amount              | Error       | Very High |                                                                       |                                                                                         |
|                      | No Physical Size       | Missing     | Low       | Unless the Item is Digital or a Variant or Relation Set.              |                                                                                         |
| Physical Size        | No Width               | Error       | Very High |                                                                       |                                                                                         |
| Physical Size        | No Height              | Error       | Very High |                                                                       |                                                                                         |
| Physical Size        | No Thickness           | Missing     | Medium    |                                                                       |                                                                                         |
|                      | No Metadata            | Error       | High      |                                                                       |                                                                                         |
| Metadata Audio       | No Subtype             | Error       | Very High |                                                                       |                                                                                         |
| Metadata Textual     | No Subtype             | Error       | Very High |                                                                       |                                                                                         |
| Metadata Textual     | No Languages           | Missing     | Medium    |                                                                       |                                                                                         |
| Metadata Textual     | No Page Count          | Missing     | Medium    |                                                                       |                                                                                         |
| Metadata Game        | No Platforms           | Missing     | Very High |                                                                       |                                                                                         |
| Metadata Game        | No Audio Languages     | Missing     | High      |                                                                       |                                                                                         |
| Metadata Game        | No Sub Languages       | Missing     | High      |                                                                       |                                                                                         |
| Metadata Game        | No Interface Languages | Missing     | High      |                                                                       |                                                                                         |
| Metadata Video       | No Subtype             | Error       | Very High |                                                                       |                                                                                         |
| Metadata Group       | No Subtype             | Error       | Very High |                                                                       |                                                                                         |
| Metadata Group       | No Subitems Type       | Missing     | High      |                                                                       |                                                                                         |
| Metadata Group       | Has Physical Size      | Error       | High      | Variant Sets and Relation Set shouldn't have a Physical Size.         |                                                                                         |
| Metadata Group       | Has Price              | Error       | High      | Variant Sets shouldn't have a Price.                                  |                                                                                         |
| Metadata Group       | Has URLs               | Error       | High      | Variant Sets shouldn't have URLs.                                     |                                                                                         |
| Metadata Group       | Has Contents           | Error       | High      | Variant Sets and Relation Set shouldn't have Contents.                |                                                                                         |
| Metadata Group       | Has Images             | Error       | High      | Variant Sets and Relation Set shouldn't have Images.                  |                                                                                         |
| Metadata Group       | No Subitems            | Missing     | High      | Group Items should have subitems.                                     |
